---
layout: blog
week: 203
published: 2019-03-20 12:51:12
---

Here's what happened in the [Reproducible Builds](https://reproducible-builds.org) effort between Sunday March 10 and Saturday March 16 2019:

* Bernhard M. Wiedemann [started a document](https://github.com/bmwiedemann/reproducibleopensuse/blob/devel/howtodebug) on how to work on reproducible builds.

* [Alexander Couzens](https://lunarius.fe80.eu) and [Holger Levsen](http://layer-acht.org/thinking/) and attended the sixth [MirageOS](https://mirage.io/) retreat in Marrakech, Morroco, to help the developers with reproducibilty issues and to do location scouting for the next [Reproducible Builds summit](https://reproducible-builds.org/events/), tentatively planned to take place in late 2019. Alexander subsequently [wrote a detailed report what he got up to](https://lunarius.fe80.eu/blog/mirageos-2019.html), specifically mentioning his work on the reproducibility of [OpenWrt](https://en.wikipedia.org/wiki/OpenWrt). Holger also did an ad-hoc presentation about the current state of Reproducible Builds. (No slides available due to the ad-hoc nature, though there is a transscript, which we'll link here once it has been edited.)

* Mattia Rizzolo updated the [reproducible-builds.org project website](https://reproducible-builds.org) to fix a build warning resulting from a misnamed/labelled empty layout.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/53df0ee)]

* [diffoscope](https://diffoscope.org/) is our in-depth "diff-on-steroids" utility which helps us diagnose reproducibility issues in packages. This week, Milena Boselli Rosa has been [working towards fixing various HTML markup warnings/errors](https://salsa.debian.org/reproducible-builds/diffoscope/merge_requests/23).

* Bernhard M. Wiedemann [proposed a toolchain patch](https://github.com/python/cpython/pull/12341) for [Python's `distutils`](https://docs.python.org/3/library/distutils.html) module to sort the list of sources would make builds of many Python modules with binary components more reproducible.

* 14 Debian package reviews were added, 7 were updated and 10 were removed in this week, adding to [our knowledge about identified issues](https://tests.reproducible-builds.org/debian/index_issues.html). A new issue type was identified and categorised by Chris Lamb ([`build_time_embedded_by_fontforge`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/4be88e6d)).

**Don't forget that Reproducible Builds is part of May/August 2019 round of [Outreachy](https://www.outreachy.org/) which offers paid internships to work on free software.** Internships are open to applicants around the world and are paid a stipend for the three month internship with an additional travel stipend to attend conferences. So far, we received more than ten initial requests from candidates and the closing date for applicants is April 2nd. More information is available [on the application page](https://www.outreachy.org/may-2019-august-2019-outreachy-internships/communities/debian/).

## Packages reviewed and fixed, and bugs filed

* Bernhard M. Wiedemann:
    * [envoy-proxy](https://build.opensuse.org/request/show/684277) (date & time in dummy [Git](https://docs.python.org/3/library/distutils.html) commit hash)
    * [kata-containers](https://github.com/kata-containers/packaging/pull/397) (override user, host & date)
    * [projectM](https://github.com/projectM-visualizer/projectm/pull/176) (sort `readdir(3)` results)
    * [python-pytest](https://github.com/pytest-dev/pytest/pull/4903) (fix build failure in 2038)
    * [python-yt](https://github.com/yt-project/yt/pull/2206) (filesystem ordering in `.so` files; sort Python [glob](https://en.wikipedia.org/wiki/Glob_(programming)))

* Chris Lamb:
    * [#924378](https://bugs.debian.org/924378) filed against [vue-router.js](https://tracker.debian.org/pkg/vue-router.js) [forwarded upstream](https://github.com/vuejs/vue-router/pull/2646).
    * [#924458](https://bugs.debian.org/924458) filed against [node-js-beautify](https://tracker.debian.org/pkg/node-js-beautify).
    * [#924462](https://bugs.debian.org/924462) filed against [node-opencv](https://tracker.debian.org/pkg/node-opencv).
    * [#924654](https://bugs.debian.org/924654) filed against [tdbc](https://tracker.debian.org/pkg/tdbc).


## strip-nondeterminism

`strip-nondeterminism` is our tool that post-processes files to remove known non-deterministic output. This week, Chris Lamb:

 * [Migrated the canonical list of issues](https://salsa.debian.org/reproducible-builds/strip-nondeterminism/issues) from the [Debian BTS](https://bugs.debian.org/src:strip-nondeterminism) to the [Salsa](https://salsa.debian.org/) GitLab instance. You can easily register for a *salsa* account by following the instructions on our [Contribute](https://reproducible-builds.org/contribute/) page.

 * Fixed an issue where `file(1)` was being called without the `--` argument placeholder to fix normalisation of files starting with a hyphen.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/strip-nondeterminism/commit/82d9ee5)]

 * [Uploaded version 1.1.2-1](https://tracker.debian.org/news/1035330/accepted-strip-nondeterminism-112-1-source-all-into-unstable/) to Debian unstable.

## Test framework development

We operate a comprehensive [Jenkins](https://jenkins.io/)-based testing framework that powers [tests.reproducible-builds.org](https://tests.reproducible-builds.org). This week, the following changes were made:

* Alexander Couzens ([OpenWrt](https://en.wikipedia.org/wiki/OpenWrt) support):
    * Correct the arguments for the `reproducible_openwrt_package_parser` script.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/32378e36)]
    * Copy over `Package-*` files when building.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/43aeb908)]
    * Fix the `Packages.manifest` parser.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/58fe7857)]&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/5908f96a)]

* Mattia Rizzolo:
    * In the `email2irc` script, correctl redirect [standard error to standard out](https://en.wikipedia.org/wiki/Standard_streams).&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/8d50f287)]
    * Do not automatically take the `pb10` node offline.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/dba4c10f)]
    * Node maintenance.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/d10114ca)]&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/3a34dc82)]&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/70f29ef3)],&nbsp;etc.


---

This week's edition was written by Arnout Engelen, Bernhard M. Wiedemann, Chris Lamb, Holger Levsen & reviewed by a bunch of Reproducible Builds folks on IRC & the mailing lists.
