---
layout: report
year: "2019"
month: "10"
title: "Reproducible Builds in October 2019"
draft: false
date: 2019-11-06 18:25:58
---

**Welcome to the October 2019 report from the [Reproducible Builds]({{ "/" | relative_url }}) project. 👌**
{: .lead}

[![]({{ "/images/reports/2019-10/reproducible-builds.png#right" | relative_url }})]({{ "/" | relative_url }})

In our monthly reports we attempt outline the most important things that we have been up to recently. As a reminder on what our little project is all about, whilst anyone can inspect the source code of free software for malicious changes most software is distributed to end users or servers as precompiled binaries. Reproducible builds tries to ensure that no changes have been made during these compilation processes by promising identical results are always generated from a given source, allowing multiple third-parties to come to a consensus on whether a build was compromised.

In this month's report, we will cover:

* **Media coverage & conferences** — *Reproducible builds in Belfast & science*
* **Reproducible Builds Summit 2019** — *Registration & attendees, etc.*
* **Distribution work** — *The latest work in Debian, OpenWrt, openSUSE, and more...*
* **Software development** — *More diffoscope development, etc.*
* **Getting in touch** — *How to contribute & get in touch*

If you are interested in contributing to our venture, please visit [our *Contribute*]({{ "/contribute/" | relative_url }}) page on our website.

---

## Media coverage & conferences

[Jonathan McDowell](https://www.earth.li/~noodles/) gave [an introduction on Reproducible Builds in Debian](https://www.meetup.com/belfast-lug/events/264951460/) at the [Belfast Linux User Group](https://www.meetup.com/belfast-lug/):

[![]({{ "/images/reports/2019-10/blug.jpg" | relative_url }})](https://twitter.com/FarsetLabs/status/1187070654383841280)

Whilst not strictly related to reproducible *builds*, Sean Gallagher from [Ars Technica](https://arstechnica.com/) wrote an article entitled [*Researchers find bug in Python script may have affected hundreds of studies*](https://arstechnica.com/information-technology/2019/10/chemists-discover-cross-platform-python-scripts-not-so-cross-platform/):

> A programming error in a set of Python scripts commonly used for computational analysis of chemistry data returned varying results based on which operating system they were run on.

---

## Reproducible Builds Summit 2019

[![]({{ "/images/reports/2019-10/summit.jpg#right" | relative_url }})]({{ "/events/Marrakesh2019/" | relative_url }})

Registration for [our fifth annual Reproducible Builds summit]({{ "/events/Marrakesh2019/" | relative_url }}) that will take place between the 1st and 8th December in Marrakesh, Morocco has opened and [invitations](https://lists.reproducible-builds.org/pipermail/rb-general/2019-September/001651.html) have been sent out.

Similar to previous incarnations of the event, the heart of the workshop will be three days of moderated sessions with surrounding "hacking" days and will include a huge diversity of participants from Arch Linux, coreboot, Debian, F-Droid, GNU Guix, Google, Huawei, in-toto, MirageOS, NYU, openSUSE, OpenWrt, Tails, Tor Project and many more. We are still seeking additional sponsorship for the event. Sponsoring enables us to enable the attendance of people who would not otherwise be able to attend. If you or your company would be able to sponsor the event, please contact `info@reproducible-builds.org`.

If you would like to learn more about the event and how to register, please visit our [our dedicated event page]({{ "/events/Marrakesh2019/" | relative_url }}).

---

### Distribution work

[![]({{ "/images/reports/2019-10/guix.png#right" | relative_url }})](http://guix.gnu.org/)

[GNU Guix](http://guix.gnu.org/) announced that they had [significantly reduced the size of their "bootstrap seed"](https://guix.gnu.org/blog/2019/guix-reduces-bootstrap-seed-by-50/) by replacing [binutils](https://en.wikipedia.org/wiki/GNU_Binutils), [GCC](https://gcc.gnu.org/) and [glibc](https://www.gnu.org/software/libc/) with smaller alternatives resulting in the package manager "possessing a formal description of how to build all underlying software" in a reproducible way from a mere 120MB seed.

[OpenWrt](https://openwrt.org/) is a Linux-based operating system targeting wireless network routers and other embedded devices. This month Paul Spooren (*aparcar*) posted a patch to their mailing list [adding `KCFLAGS` to the kernel build flags](https://lists.infradead.org/pipermail/openwrt-devel/2019-October/019248.html) to make it easier to rebuild the official binaries.

[![]({{ "/images/reports/2019-10/opensuse.png#right" | relative_url }})](https://www.opensuse.org/)

Bernhard M. Wiedemann posted [his monthly Reproducible Builds status update](https://lists.opensuse.org/opensuse-factory/2019-10/msg00367.html) for the [openSUSE](https://opensuse.org/) distribution which describes how [`rpm` was updated](https://build.opensuse.org/request/show/732635) to run most builds with the `-flto=auto` argument, saving mirror disk space/bandwidth. In addition, [`maven-javadoc-plugin` received a toolchain patch](https://build.opensuse.org/request/show/735873) ([originating from Debian](https://salsa.debian.org/java-team/maven-javadoc-plugin/blob/master/debian/patches/reproducible-footer.patch)) in order to normalise a date.

#### Debian

[![]({{ "/images/reports/2019-10/debian.png#right" | relative_url }})](https://debian.org/)

In Debian this month Didier Raboud (*OdyX*) started a discussion on the [`debian-devel`](https://lists.debian.org/debian-devel/) mailing list regarding building Debian source packages in a reproducible manner ([thread index](https://lists.debian.org/debian-devel/2019/10/threads.html#00301)). In addition, Lukas Pühringer prepared an upload of [`in-toto`](https://in-toto.io/), a framework to protect supply chain integrity by the [Secure Systems Lab](https://ssl.engineering.nyu.edu/) at [New York University](https://engineering.nyu.edu/) which was uploaded by Holger Levsen.

Holger Levsen started a new section on the [Debian wiki](https://wiki.debian.org/) to centralise to [document the progress made on various Debian-specific reproducibility issues](https://wiki.debian.org/ReproducibleBuilds#Solved_issues) and noticed that the ["essential" package set in the *bullseye* distribution](https://tests.reproducible-builds.org/debian/buster/amd64/pkg_set_essential.html) became unreproducible again, likely due to a a [bug in Perl](https://bugs.debian.org/791362) itself. Holger also [restarted a discussion](https://bugs.debian.org/774415#270) on Debian bug [#774415](https://bugs.debian.org/774415) which requests that the `devscripts` collection of utilities that "make the life of a Debian package maintainer easier" adds a script/wrapper to enable easier end-user testing of whether a package is reproducible.

Johannes Schauer (*josch*) explained that their [`mmdebstrap`](https://tracker.debian.org/mmdebstrap) tool [can create bit-for-bit identical](https://lists.debian.org/debian-devel/2019/10/msg00101.html) Debian [chroots](https://en.wikipedia.org/wiki/Chroot) of the *unstable* and *buster* distributions for both the `essential` and `minbase` [bootstrap "variants"](https://sources.debian.org/src/debootstrap/1.0.116/debootstrap.8/#L78-L85), and Bernhard M. Wiedemann [contributed to a discussion](https://bugs.debian.org/940571#26) regarding adding a "global" build switch to enable/disable [Profile-Guided Optimisation](https://en.wikipedia.org/wiki/Profile-guided_optimization) (PGO) and [Link-time optimisation](https://en.wikipedia.org/wiki/Interprocedural_optimization) in the `dpkg-buildflags` tool, nothing that "overall it is still very hard to get reproducible builds with PGO enabled."

64 reviews of Debian packages were added, 10 were updated and 35 were removed this month adding to [our knowledge about identified issues](https://tests.reproducible-builds.org/debian/index_issues.html). Three new types were added by Chris Lamb (*lamby*): [`nondeterministic_output_in_code_generated_by_ros_genpy`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/d219f18a), [`nondeterministic_ordering_in_include_graphs_generated_by_doxygen`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/25771b7c) & [`nondeterministic_defaults_in_documentation_generated_by_python_traitlets`](https://salsa.debian.org/reproducible-builds/reproducible-notes/commit/3ecdc853).

Lastly, there was a far-reaching discussion regarding the correctness and suitability of setting the `TZ` [environment variable](https://en.wikipedia.org/wiki/Environment_variable#Unix_2) to `UTC` when [it was noted that the value `UTC0`](https://lists.reproducible-builds.org/pipermail/rb-general/2019-October/001697.html) was "technically" more correct.

---

## Software development

#### Upstream patches

The Reproducible Builds project detects, dissects and attempts to fix as many currently-unreproducible packages as possible. We endeavour to send all of our patches upstream where appropriate. This month, we wrote a large number of such patches, including:

* Bernhard M. Wiedemann:
    * [`keeperrl`](https://github.com/miki151/keeperrl/pull/1489) (merged, date)
    * [`sphinx-doc`](https://github.com/sphinx-doc/sphinx/issues/6714) (nondeterminism from parallelism via [Sphinx](http://www.sphinx-doc.org/en/master/))
    * [`vlc`](https://mailman.videolan.org/pipermail/vlc-devel/2019-October/128188.html) (sort tar)
    * A number of expiring SSL testing certificates have been extended to 2049 to fix future builds:
        * [`python-M2Crypto`](https://gitlab.com/m2crypto/m2crypto/merge_requests/235)
        * [`python-aiosmtplib`](https://github.com/cole/aiosmtplib/pull/92)
        * [`python-distlib`](https://bitbucket.org/pypa/distlib/pull-requests/44/extend-test-cert-validity-to-2049/diff)
        * [`python-geventhttpclient`](https://github.com/gwik/geventhttpclient/pull/115)
        * [`python-moto`](https://github.com/spulec/moto/pull/2500) (has a remaining year 2038 bug)
        * [`python-oslo.service`](https://review.opendev.org/687822)
        * [`python-thriftpy2`](https://github.com/Thriftpy/thriftpy2/pull/91)

* Chris Lamb (*lamby*):
    * [#934698](https://bugs.debian.org/934698) filed against [`libchamplain`](https://tracker.debian.org/pkg/libchamplain) ([merged upstream](https://gitlab.gnome.org/GNOME/libchamplain/merge_requests/9)).
    * [#941714](https://bugs.debian.org/941714) filed against [`bst-external`](https://tracker.debian.org/pkg/bst-external).
    * [#941715](https://bugs.debian.org/941715) filed against [`checkinstall`](https://tracker.debian.org/pkg/checkinstall).
    * [#941716](https://bugs.debian.org/941716) filed against [`gobject-introspection`](https://tracker.debian.org/pkg/gobject-introspection).
    * [#942005](https://bugs.debian.org/942005) filed against [`elph`](https://tracker.debian.org/pkg/elph).
    * [#942006](https://bugs.debian.org/942006) filed against [`squeak-plugins-scratch`](https://tracker.debian.org/pkg/squeak-plugins-scratch).
    * [#942009](https://bugs.debian.org/942009) filed against [`stgit`](https://tracker.debian.org/pkg/stgit) ([forwarded upstream](https://github.com/ctmarinas/stgit/pull/43)).
    * [#942342](https://bugs.debian.org/942342) filed against [`traitlets`](https://tracker.debian.org/pkg/traitlets) ([forwarded upstream](https://github.com/ipython/traitlets/pull/535)).
    * [#942479](https://bugs.debian.org/942479) filed against [`frobby`](https://tracker.debian.org/pkg/frobby).
    * [#942767](https://bugs.debian.org/942767) filed against [`python-oslo.reports`](https://tracker.debian.org/pkg/python-oslo.reports).
    * [#942847](https://bugs.debian.org/942847) filed against [`cloudkitty`](https://tracker.debian.org/pkg/cloudkitty).
    * [#942848](https://bugs.debian.org/942848) filed against [`designate`](https://tracker.debian.org/pkg/designate).
    * [#942867](https://bugs.debian.org/942867) & [#942870](https://bugs.debian.org/942870) filed against [`r-base`](https://tracker.debian.org/pkg/r-base) (not respecting `nocheck` and `nodoc` [Debian build profiles](https://wiki.debian.org/BuildProfileSpec)).
    * [#943471](https://bugs.debian.org/943471) filed against [`khard`](https://tracker.debian.org/pkg/khard) ([forwarded upstream](https://github.com/scheibler/khard/pull/233)).
    * [#943674](https://bugs.debian.org/943674) filed against [`flask`](https://tracker.debian.org/pkg/flask) ([forwarded upstream](https://github.com/pallets/flask/pull/3408)).
    * [#943694](https://bugs.debian.org/943694) filed against [`ros-genpy`](https://tracker.debian.org/pkg/ros-genpy) ([forwarded upstream](https://github.com/ros/genpy/pull/110)).
    * [#943829](https://bugs.debian.org/943829) filed against [`pmemkv`](https://tracker.debian.org/pkg/pmemkv).
    * [#943954](https://bugs.debian.org/943954) filed against [`tm-align`](https://tracker.debian.org/pkg/tm-align).
    * [#943956](https://bugs.debian.org/943956) filed against [`snakemake`](https://tracker.debian.org/pkg/snakemake) ([forwarded upstream](https://github.com/snakemake/snakemake/pull/80))
    * [`spirv-tools`](https://github.com/KhronosGroup/SPIRV-Tools/pull/2982).

* Mattias Ellert:
    * [#942671](https://bugs.debian.org/942671) filed against [`doxygen`](https://tracker.debian.org/pkg/doxygen).

Lastly, a request from [Steven Engler](https://github.com/stevenengler) to sort fields in the `PKG-INFO` files generated by the [setuptools](https://pypi.org/project/setuptools/) Python module build utilities [was resolved](https://github.com/pypa/setuptools/pull/1305#issuecomment-538810632) by [Jason R. Coombs](https://www.jaraco.com/) and Vagrant Cascadian added [`SOURCE_DATE_EPOCH`](https://reproducible-builds.org/docs/source-date-epoch/) support to [LTSP](https://ltsp.github.io/)'s manual page generation.

#### strip-nondeterminism & reprotest

[strip-nondeterminism](https://tracker.debian.org/pkg/strip-nondeterminism) is our tool to remove specific non-deterministic results from successful builds. This month, Chris Lamb made a number of changes including [uploading version `1.6.1-1` was to Debian unstable](https://tracker.debian.org/news/1071922/accepted-strip-nondeterminism-161-1-source-into-unstable/). This dropped the `bug_803503.zip` test fixture as it is no longer compatible with the latest version of Perl's [`Archive::Zip`](https://metacpan.org/pod/Archive::Zip) module ([#940973](https://bugs.debian.org/940973)).

`reprotest` is our end-user tool to build same source code twice in widely differing environments and then checks the binaries produced by each build for any differences. This month, Iñaki Malerba updated our [Salsa CI](https://salsa.debian.org) scripts&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reprotest/commit/a547967)] as well as adding a `--control-build` parameter&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reprotest/commit/52f6eeb)]. Holger Levsen uploaded the package as `0.7.10`, bumping the Debian ["standards version"](https://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-standards-version) to `4.4.1`&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reprotest/commit/fa0e286)].

#### [diffoscope](https://diffoscope.org)

[![]({{ "/images/reports/2019-10/diffoscope.svg#right" | relative_url }})](https://diffoscope.org)

[`diffoscope`](https://diffoscope.org) is our in-depth and content-aware diff utility that can locate and diagnose reproducibility issues. It is run countless times a day on [our testing infrastructure](https://tests.reproducible-builds.org/debian/reproducible.html) and is essential for identifying fixes and causes of non-deterministic behaviour.

This month, Chris Lamb (*lamby*) made the following changes, including uploading versions `126`, `127`, `128` and `129` to the Debian *unstable* distribution:

* Disassembling and reporting on files related to the [R (programming language)](https://en.wikipedia.org/wiki/R_(programming_language)):

    * Expose an `.rdb` file's absolute paths in the semantic/human-readable output, not hidden deep in a hexdump.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f1e80ca)]
    * Rework and refactor the handling of `.rdb` files with respect to locating the parallel `.rdx` prior to inspecting the file to ensure that we do not add files to the user's filesystem in the case of directly comparing two `.rdb` files or — worse — overwriting a file in is place.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/ea4c94a)]
    * Query the container for the full path of the parallel `.rdx` file to the `.rdb` file as well as looking in the same directory. This ensures that comparing two Debian packages shows any varying path.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/322a568)]
    * Correct the matching of `.rds` files by also detecting newer versions of this file format.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/2c9fbc1)]
    * Don't read the site and user environment when comparing `.rdx`, `.rdb` or `.rds` files by using `Rscript`'s `--vanilla` option.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/b8236d4)][[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f8e436d)]
    * Ensure all object names are displayed, including ones beginning with a fullstop (`.`) [[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/1f89609)] and sort package fields when dumping data from `.rdb` files [[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/9f60724)].
    * Mask/hide standard error when processing `.rdb` files [[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/0092be0)] and don't include useless/misleading `NULL` when dumping data from them.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/cb83076)]
    * Format package contents as `foo = bar` rather than using ugly and misleading brackets, etc.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/343d01d)] and include the object's type [[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/895f398)].
    * Don't pass our long script to parse `.rdb` files via the command line; use [standard input](https://en.wikipedia.org/wiki/Standard_streams#Standard_input_(stdin)) instead.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/07a013f)]
    * Call the `deparse` function to ensure that we do not error out and revert to a binary diff when processing `.rdb` files with internal "vector" types; they do not automatically coerce to strings.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/91d7029)]
    * Other misc/cosmetic changes.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/c23651e)][[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/face6fb)][[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f23f2b4)]

* Output/logging:
    * When printing an error from a command, format the command for the user.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/138aac1)]
    * Truncate very long command lines when displaying them as an external source of data.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/ecccd71)]
    * When formatting command lines ensure newlines and other metacharacters appear escaped as `\n`, etc.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/691ce88)][[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/338dbdf)]
    * When displaying the standard error from commands, ensure we use the escaped version.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/bbfdb57)]
    * Use "exit code" over "return code" terminology when referring to UNIX error codes in displayed differences.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/6a8251d)]

* Internal API:
    * Add ability to pass [bytestring](https://docs.python.org/3/library/stdtypes.html#bytes) input to external commands.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/c525ba9)]
    * Split out command-line formatting into a separate utility function.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f784d2c)]
    * Add support for easily masking the standard error of commands.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/9b5c5fd)][[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/2e33ad6)]
    * To match the [libarchive](https://www.libarchive.org/) container, raise a `KeyError` exception if we request an invalid member from a directory.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/c98e40f)]
    * Correct string representation output in the traceback when we cannot locate a specific item in a container.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/2478e9c)]

* Misc:
    * Move build-dependency on `python-argcomplete` to its Python 3 equivalent to facilitate Python 2.x removal. ([#942967](https://bugs.debian.org/942967))
    * Track and report on missing Python modules. ([#72](https://salsa.debian.org//diffoscope/reproducible-builds/diffoscope))
    * Move from deprecated `$ADTTMP` to `$AUTOPKGTEST_TMP` in the [autopkgtests](https://ci.debian.net/).&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/f06c44f)]
    * Truncate the tcpdump expected diff to 8KB (from ~600KB).&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/c6517e6)]
    * Try and ensure that new test data files are generated dynamically, ie. at least no new ones are added without "good" reasons.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/e83b360)]
    * Drop unused `BASE_DIR` global in the tests.&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/7b44c80)]

In addition, Mattia Rizzolo updated our tests to run against all supported Python versions&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/23c6112)] and to exit with a [UNIX exit status](https://en.wikipedia.org/wiki/Exit_status) of `2` instead of `1` in case of running out of disk space&nbsp;[[...](https://salsa.debian.org/reproducible-builds/diffoscope/commit/59267e8)]. Lastly Vagrant Cascadian updated diffoscope [126](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=c3704ecaa537f96dfca2f820c3af5357a6208ce6) and  [129](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=d332fd860f89ed426a2b05eaa8f7a76ff6aab58f) in [GNU Guix](https://guix.gnu.org/), and updated inputs for additional [test suite coverage](https://git.savannah.gnu.org/cgit/guix.git/commit/?id=36f5f23c1af640782aa47dbfed6352e3d4c957ff).

[trydiffoscope](https://try.diffoscope.org) is the web-based version of [diffoscope](https://diffoscope.org) and this month Chris Lamb migrated the tool to depend on the `python3-docutils` package over `python-docutils` to allow for Python 2.x removal ([#943293](https://bugs.debian.org/943293)) as well as updating the packaging to the latest Debian standards and conventions&nbsp;[[...](https://salsa.debian.org/reproducible-builds/trydiffoscope/commit/75e8b14)][[...](https://salsa.debian.org/reproducible-builds/trydiffoscope/commit/95d7faf)][[...](https://salsa.debian.org/reproducible-builds/trydiffoscope/commit/01df0a4)].

#### Project website

[![]({{ "/images/reports/2019-10/website.png#right" | relative_url }})](https://reproducible-builds.org/)

There was yet more effort put into our [our website](https://reproducible-builds.org/) this month, including Chris Lamb improving the formatting of reports &nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/db5e808)][[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/4594e05)][[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/f338c38)][[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/46b66fc)][[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/ad390e8)] and tidying the new ["Testing framework"](https://tests.reproducible-builds.org/debian/reproducible.html) links&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/137e4bd)], etc.

In addition, Holger Levsen add the Tor Project's [Reproducible Builds Manager](https://rbm.torproject.org/) to our "[Who is Involved?](https://reproducible-builds.org/who/)" page and Mattia Rizzolo dropped a literal `<br>` HTML element&nbsp;[[...](https://salsa.debian.org/reproducible-builds/reproducible-website/commit/8b69f7d)].

#### Test framework

[![]({{ "/images/reports/2019-10/testframework.png#right" | relative_url }})](https://tests.reproducible-builds.org/)

We operate a comprehensive [Jenkins](https://jenkins.io/)-based testing framework that powers [tests.reproducible-builds.org](https://tests.reproducible-builds.org). This month, the following changes were made:

* Holger Levsen:
    * [Debian](https://debian.org/)-specific changes:
        * Add a script to ease powercycling `x86` and `arm64` nodes.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/8a69efc8)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/64d87e9e)]
        * Don't create suite-based directories for [buildinfos.debian.net](https://buildinfos.debian.net/).&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/e4a15fc4)]
        * Make all four suites being tested shown in a single row on the performance page.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/cd8f363f)]

    * [OpenWrt](https://openwrt.org) changes:
        * Only run jobs every third day.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/d75af2d4)]
        * Create jobs to run the `reproducible_openwrt_rebuild.py` script today and in the future.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/fa9febb0)]

* Mattia Rizzolo:
    * Add some packages that were lost while updating to *buster*.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/69c765d7)]
    * Fix the auto-offline functionality by checking the content of the `permalinks` file instead of following the `lastSuccessfulBuild` that no longer being updated.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/a395b84f)]

* Paul Spooren ([OpenWrt](https://openwrt.org)):
    * Add a `reproducible_common` utilities file.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/94dcfb4c)]
    * Update the `openwrt-rebuild` script to to use `schroot`.&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/f73cf72f)]
    * Use [unbuffered](https://eklitzke.org/stdout-buffering) Python output&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/e2630fb7)] as well as fixing newlines&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/dcbacce5)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/0443a133)]

The usual node maintenance was performed by Holger Levsen&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/cfbc58fb)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/5f9424da)], Mattia Rizzolo&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/9d3df188)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/88db9f0a)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/5cdad8fd)] and Vagrant Cascadian&nbsp;[[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/974bca24)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/8d4b533c)][[...](https://salsa.debian.org/qa/jenkins.debian.net/commit/3da81a76)].

---

## Getting in touch

If you are interested in contributing the Reproducible Builds project, please visit our [*Contribute*](https://reproducible-builds.org/contribute/) page on our website. However, you can get in touch with us via:

 * Mailing list: [`rb-general@lists.reproducible-builds.org`](https://lists.reproducible-builds.org/listinfo/rb-general)

 * IRC: `#reproducible-builds` on `irc.oftc.net`.

 * Twitter: [@ReproBuilds](https://twitter.com/ReproBuilds)

<br>

---

This month's report was written by Bernhard M. Wiedemann, Chris Lamb, Holger Levesen and Vagrant Cascadian. It was subsequently reviewed by a bunch of Reproducible Builds folks on IRC and the mailing list.
